nrf-pac

Crates

git

Versions

nrf5340-app

Flavors

AesControl

Struct AesControl 

#[repr(transparent)]
pub struct AesControl(pub u32);
Control the AES engine behavior.

Tuple Fields

0: u32

Implementations

Source

impl AesControl

pub const fn dec_key0(&self) -> DecKey0

Set AES encrypt or decrypt mode in non-tunneling operations.

pub const fn set_dec_key0(&mut self, val: DecKey0)

Set AES encrypt or decrypt mode in non-tunneling operations.

pub const fn mode0_is_cbc_cts(&self) -> bool

This field allows to add distinction to the CBC and CTR modes defined in field MODE_KEY0. If MODE_KEY0 is set to CBC in combination with this field, AES mode is CBC-CTS. If MODE_KEY0 is set to CTR in combination with this field, AES mode is GCTR.

pub const fn set_mode0_is_cbc_cts(&mut self, val: bool)

This field allows to add distinction to the CBC and CTR modes defined in field MODE_KEY0. If MODE_KEY0 is set to CBC in combination with this field, AES mode is CBC-CTS. If MODE_KEY0 is set to CTR in combination with this field, AES mode is GCTR.

pub const fn mode_key0(&self) -> ModeKey0

Set the AES mode in non-tunneling operations, or the AES mode of the first stage in tunneling operations.

pub const fn set_mode_key0(&mut self, val: ModeKey0)

Set the AES mode in non-tunneling operations, or the AES mode of the first stage in tunneling operations.

pub const fn mode_key1(&self) -> ModeKey1

Set the AES mode of the second stage in tunneling operations

pub const fn set_mode_key1(&mut self, val: ModeKey1)

Set the AES mode of the second stage in tunneling operations

pub const fn cbc_is_essiv(&self) -> bool

If MODE_KEY0 is set to CBC, and this field is set, the mode is CBC with ESSIV.

pub const fn set_cbc_is_essiv(&mut self, val: bool)

If MODE_KEY0 is set to CBC, and this field is set, the mode is CBC with ESSIV.

pub const fn aes_tunnel(&self) -> bool

Configure AES engine for standard non-tunneling or tunneling operations.

pub const fn set_aes_tunnel(&mut self, val: bool)

Configure AES engine for standard non-tunneling or tunneling operations.

pub const fn cbc_is_bitlocker(&self) -> bool

If MODE_KEY0 is set to CBC, and this field is set, the mode is CBC Bitlocker.

pub const fn set_cbc_is_bitlocker(&mut self, val: bool)

If MODE_KEY0 is set to CBC, and this field is set, the mode is CBC Bitlocker.

pub const fn nk_key0(&self) -> NkKey0

Set the AES key length in non-tunneling operations, or the AES key length of the first stage in tunneling operations.

pub const fn set_nk_key0(&mut self, val: NkKey0)

Set the AES key length in non-tunneling operations, or the AES key length of the first stage in tunneling operations.

pub const fn nk_key1(&self) -> NkKey1

Set the AES key length of the second stage in tunneling operations.

pub const fn set_nk_key1(&mut self, val: NkKey1)

Set the AES key length of the second stage in tunneling operations.

pub const fn aes_tunnel1_decrypt(&self) -> AesTunnel1Decrypt

Configure if first tunnel stage performs encrypt or decrypt operation.

pub const fn set_aes_tunnel1_decrypt(&mut self, val: AesTunnel1Decrypt)

Configure if first tunnel stage performs encrypt or decrypt operation.

pub const fn aes_tun_b1_uses_padded_data_in(&self) -> bool

For tunneling operations this field determine the data that is fed to the second tunneling stage.

pub const fn set_aes_tun_b1_uses_padded_data_in(&mut self, val: bool)

For tunneling operations this field determine the data that is fed to the second tunneling stage.

pub const fn aes_tunnel0_encrypt(&self) -> AesTunnel0Encrypt

Configure if first tunnel stage performs encrypt or decrypt operation.

pub const fn set_aes_tunnel0_encrypt(&mut self, val: AesTunnel0Encrypt)

Configure if first tunnel stage performs encrypt or decrypt operation.

pub const fn aes_output_mid_tunnel_data(&self) -> AesOutputMidTunnelData

This fields configure if the AES engine output is the result of the first or second tunneling stage.

pub const fn set_aes_output_mid_tunnel_data( &mut self, val: AesOutputMidTunnelData, )

This fields configure if the AES engine output is the result of the first or second tunneling stage.

pub const fn aes_tunnel_b1_pad_en(&self) -> bool

This field configure if the input data to the second tunnel stage is to be padded with zeroes according to how many bytes are remaining.

pub const fn set_aes_tunnel_b1_pad_en(&mut self, val: bool)

This field configure if the input data to the second tunnel stage is to be padded with zeroes according to how many bytes are remaining.

pub const fn aes_out_mid_tun_to_hash(&self) -> AesOutMidTunToHash

This field determines for AES-TO-HASH-AND-DOUT tunneling operations, whether the AES outputs to the HASH the result of the first or the second tunneling stage.

pub const fn set_aes_out_mid_tun_to_hash(&mut self, val: AesOutMidTunToHash)

This field determines for AES-TO-HASH-AND-DOUT tunneling operations, whether the AES outputs to the HASH the result of the first or the second tunneling stage.

pub const fn direct_access(&self) -> bool

Using direct access and not the DIN-DOUT DMA interface

pub const fn set_direct_access(&mut self, val: bool)

Using direct access and not the DIN-DOUT DMA interface